@@ -135,7 +135,7 @@ class GRPCDataChannel(DataChannel):
             elif future.done() and future.exception() is not None:
                 raise future.exception()
             else:
-                sleep(1)
+                sleep(0.1)
                 current = datetime.utcnow().timestamp()
         raise SendingError(f'timeout to sending data stream to {target}')
 
@@ -480,7 +480,7 @@ class GRPCDataChannel(DataChannel):
             if all(_future.done() for _future in futures.values()):
                 break
             else:
-                sleep(1)
+                sleep(0.1)
                 current = datetime.utcnow().timestamp()
 
         for _target, _future in futures.items():
