@@ -11,19 +11,15 @@ import torchvision
 from torch import optim
 from torch.utils.data import DataLoader
 
-from ... import DEV_TASK_ID, logger
+from ... import logger
 from ...fed_avg import (FedAvgScheduler, FedSGDScheduler,
                         SecureFedAvgScheduler, register_metrics)
 from ...fed_avg.dp_fed_avg import DPFedAvgScheduler
+from . import DEV_TASK_ID
 from .demo_FedIRM import DemoFedIRM
 
 CURRENT_DIR = os.path.dirname(os.path.abspath(__file__))
 
-AGGREGATOR_ID = 'QmegaqF4RjBjN3i4NdJy24svtFkJAUXc3YUFqRKqNjaAw4'
-DATA_OWNER_3_ID = 'QmP4DksaGVrFgkNp3d4NxZnnb4RtQucpMqLESJTAEAtuxC'
-DATA_OWNER_4_ID = 'QmWuc1GSaqCkUajoPG5QHfeh72YqU4N7VH7Nx2eP6FyJ9M'
-DATA_OWNER_5_ID = 'QmRj3kV7uQeCndrJvYYFHwfDoQmFdxNkCqpiL7m7VanKfw'
-
 
 VANILLA = 'vanilla'
 SGD = 'sgd'
